#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['packageManifest',
 'packageManifest.globalName',
 'packageManifest.globalName.tests',
 'packageManifest.localName',
 'packageManifest.localName.tests',
 'packageManifest.path',
 'packageManifest.path.tests',
 'packageManifest.recursive',
 'packageManifest.recursive.tests',
 'packageManifest.tests',
 'packageManifest.tree',
 'packageManifest.tree.tests',
 'packageManifest.yamlParser',
 'packageManifest.yamlParser.tests']

package_data = \
{'': ['*'], 'packageManifest.tests': ['data/*']}

install_requires = \
['pyyaml']

setup(name='packageManifest',
      version='0.2.0',
      description='A YAML based file package-manifest framework for defining packages.',
      author='Russell Smiley',
      author_email='im.russell.smiley@gmail.com',
      url='https://gitlab.com/blueskyjunkie/package-manifest',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3',
     )
